---
title: <span class="badge object-type-scalar"></span> MegaHashesPerSecond
---
# <span class="badge object-type-scalar"></span> MegaHashesPerSecond

Hash rate: megahashes/sec

## Definition

```python
# Hash rate: megahashes/sec
MegaHashesPerSecond: typing.Literal["MHs"] = "MHs"
```
